import sys

if sys.platform == "win32":
    from je_auto_control.windows.core.util.win32_vk import ABSOLUTE
    from je_auto_control.windows.core.util.win32_vk import EventF_EXTENDEDKEY
    from je_auto_control.windows.core.util.win32_vk import EventF_KEYUP
    from je_auto_control.windows.core.util.win32_vk import EventF_SCANCODE
    from je_auto_control.windows.core.util.win32_vk import EventF_UNICODE
    from je_auto_control.windows.core.util.win32_vk import HWHEEL
    from je_auto_control.windows.core.util.win32_vk import LEFTDOWN
    from je_auto_control.windows.core.util.win32_vk import LEFTUP
    from je_auto_control.windows.core.util.win32_vk import MIDDLEDOWN
    from je_auto_control.windows.core.util.win32_vk import MIDDLEUP
    from je_auto_control.windows.core.util.win32_vk import MOVE
    from je_auto_control.windows.core.util.win32_vk import RIGHTDOWN
    from je_auto_control.windows.core.util.win32_vk import RIGHTUP
    from je_auto_control.windows.core.util.win32_vk import VK_ACCEPT
    from je_auto_control.windows.core.util.win32_vk import VK_ADD
    from je_auto_control.windows.core.util.win32_vk import VK_APPS
    from je_auto_control.windows.core.util.win32_vk import VK_BACK
    from je_auto_control.windows.core.util.win32_vk import VK_BROWSER_BACK
    from je_auto_control.windows.core.util.win32_vk import VK_BROWSER_FAVORITES
    from je_auto_control.windows.core.util.win32_vk import VK_BROWSER_FORWARD
    from je_auto_control.windows.core.util.win32_vk import VK_BROWSER_REFRESH
    from je_auto_control.windows.core.util.win32_vk import VK_BROWSER_SEARCH
    from je_auto_control.windows.core.util.win32_vk import VK_BROWSER_STOP
    from je_auto_control.windows.core.util.win32_vk import VK_CANCEL
    from je_auto_control.windows.core.util.win32_vk import VK_CAPITAL
    from je_auto_control.windows.core.util.win32_vk import VK_CLEAR
    from je_auto_control.windows.core.util.win32_vk import VK_CONTROL
    from je_auto_control.windows.core.util.win32_vk import VK_CONVERT
    from je_auto_control.windows.core.util.win32_vk import VK_DECIMAL
    from je_auto_control.windows.core.util.win32_vk import VK_DELETE
    from je_auto_control.windows.core.util.win32_vk import VK_DIVIDE
    from je_auto_control.windows.core.util.win32_vk import VK_DOWN
    from je_auto_control.windows.core.util.win32_vk import VK_END
    from je_auto_control.windows.core.util.win32_vk import VK_ESCAPE
    from je_auto_control.windows.core.util.win32_vk import VK_EXECUTE
    from je_auto_control.windows.core.util.win32_vk import VK_F1
    from je_auto_control.windows.core.util.win32_vk import VK_F10
    from je_auto_control.windows.core.util.win32_vk import VK_F11
    from je_auto_control.windows.core.util.win32_vk import VK_F12
    from je_auto_control.windows.core.util.win32_vk import VK_F13
    from je_auto_control.windows.core.util.win32_vk import VK_F14
    from je_auto_control.windows.core.util.win32_vk import VK_F15
    from je_auto_control.windows.core.util.win32_vk import VK_F16
    from je_auto_control.windows.core.util.win32_vk import VK_F17
    from je_auto_control.windows.core.util.win32_vk import VK_F18
    from je_auto_control.windows.core.util.win32_vk import VK_F19
    from je_auto_control.windows.core.util.win32_vk import VK_F2
    from je_auto_control.windows.core.util.win32_vk import VK_F20
    from je_auto_control.windows.core.util.win32_vk import VK_F21
    from je_auto_control.windows.core.util.win32_vk import VK_F22
    from je_auto_control.windows.core.util.win32_vk import VK_F23
    from je_auto_control.windows.core.util.win32_vk import VK_F24
    from je_auto_control.windows.core.util.win32_vk import VK_F3
    from je_auto_control.windows.core.util.win32_vk import VK_F4
    from je_auto_control.windows.core.util.win32_vk import VK_F5
    from je_auto_control.windows.core.util.win32_vk import VK_F6
    from je_auto_control.windows.core.util.win32_vk import VK_F7
    from je_auto_control.windows.core.util.win32_vk import VK_F8
    from je_auto_control.windows.core.util.win32_vk import VK_F9
    from je_auto_control.windows.core.util.win32_vk import VK_FINAL
    from je_auto_control.windows.core.util.win32_vk import VK_HANJA
    from je_auto_control.windows.core.util.win32_vk import VK_HELP
    from je_auto_control.windows.core.util.win32_vk import VK_HOME
    from je_auto_control.windows.core.util.win32_vk import VK_IME_OFF
    from je_auto_control.windows.core.util.win32_vk import VK_IME_ON
    from je_auto_control.windows.core.util.win32_vk import VK_INSERT
    from je_auto_control.windows.core.util.win32_vk import VK_JUNJA
    from je_auto_control.windows.core.util.win32_vk import VK_KANA
    from je_auto_control.windows.core.util.win32_vk import VK_LAUNCH_APP1
    from je_auto_control.windows.core.util.win32_vk import VK_LAUNCH_APP2
    from je_auto_control.windows.core.util.win32_vk import VK_LAUNCH_MAIL
    from je_auto_control.windows.core.util.win32_vk import VK_LAUNCH_MEDIA_SELECT
    from je_auto_control.windows.core.util.win32_vk import VK_LBUTTON
    from je_auto_control.windows.core.util.win32_vk import VK_LCONTROL
    from je_auto_control.windows.core.util.win32_vk import VK_LEFT
    from je_auto_control.windows.core.util.win32_vk import VK_LMENU
    from je_auto_control.windows.core.util.win32_vk import VK_LSHIFT
    from je_auto_control.windows.core.util.win32_vk import VK_LWIN
    from je_auto_control.windows.core.util.win32_vk import VK_MBUTTON
    from je_auto_control.windows.core.util.win32_vk import VK_MEDIA_NEXT_TRACK
    from je_auto_control.windows.core.util.win32_vk import VK_MEDIA_PLAY_PAUSE
    from je_auto_control.windows.core.util.win32_vk import VK_MEDIA_PREV_TRACK
    from je_auto_control.windows.core.util.win32_vk import VK_MEDIA_STOP
    from je_auto_control.windows.core.util.win32_vk import VK_MODECHANGE
    from je_auto_control.windows.core.util.win32_vk import VK_MULTIPLY
    from je_auto_control.windows.core.util.win32_vk import VK_Menu
    from je_auto_control.windows.core.util.win32_vk import VK_NEXT
    from je_auto_control.windows.core.util.win32_vk import VK_NONCONVERT
    from je_auto_control.windows.core.util.win32_vk import VK_NUMLOCK
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD0
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD1
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD2
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD3
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD4
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD5
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD6
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD7
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD8
    from je_auto_control.windows.core.util.win32_vk import VK_NUMPAD9
    from je_auto_control.windows.core.util.win32_vk import VK_PAUSE
    from je_auto_control.windows.core.util.win32_vk import VK_PRINT
    from je_auto_control.windows.core.util.win32_vk import VK_PRIOR
    from je_auto_control.windows.core.util.win32_vk import VK_RBUTTON
    from je_auto_control.windows.core.util.win32_vk import VK_RCONTROL
    from je_auto_control.windows.core.util.win32_vk import VK_RETURN
    from je_auto_control.windows.core.util.win32_vk import VK_RIGHT
    from je_auto_control.windows.core.util.win32_vk import VK_RMENU
    from je_auto_control.windows.core.util.win32_vk import VK_RSHIFT
    from je_auto_control.windows.core.util.win32_vk import VK_RWIN
    from je_auto_control.windows.core.util.win32_vk import VK_SCROLL
    from je_auto_control.windows.core.util.win32_vk import VK_SELECT
    from je_auto_control.windows.core.util.win32_vk import VK_SEPARATOR
    from je_auto_control.windows.core.util.win32_vk import VK_SHIFT
    from je_auto_control.windows.core.util.win32_vk import VK_SLEEP
    from je_auto_control.windows.core.util.win32_vk import VK_SNAPSHOT
    from je_auto_control.windows.core.util.win32_vk import VK_SPACE
    from je_auto_control.windows.core.util.win32_vk import VK_SUBTRACT
    from je_auto_control.windows.core.util.win32_vk import VK_TAB
    from je_auto_control.windows.core.util.win32_vk import VK_UP
    from je_auto_control.windows.core.util.win32_vk import VK_VOLUME_DOWN
    from je_auto_control.windows.core.util.win32_vk import VK_VOLUME_MUTE
    from je_auto_control.windows.core.util.win32_vk import VK_VOLUME_UP
    from je_auto_control.windows.core.util.win32_vk import VK_XBUTTON1
    from je_auto_control.windows.core.util.win32_vk import VK_XBUTTON2
    from je_auto_control.windows.core.util.win32_vk import VkToVSC
    from je_auto_control.windows.core.util.win32_vk import WHEEL
    from je_auto_control.windows.core.util.win32_vk import XBUTTON1
    from je_auto_control.windows.core.util.win32_vk import XBUTTON2
    from je_auto_control.windows.core.util.win32_vk import XDOWN
    from je_auto_control.windows.core.util.win32_vk import XUP
    from je_auto_control.windows.core.util.win32_vk import key0
    from je_auto_control.windows.core.util.win32_vk import key1
    from je_auto_control.windows.core.util.win32_vk import key2
    from je_auto_control.windows.core.util.win32_vk import key3
    from je_auto_control.windows.core.util.win32_vk import key4
    from je_auto_control.windows.core.util.win32_vk import key5
    from je_auto_control.windows.core.util.win32_vk import key6
    from je_auto_control.windows.core.util.win32_vk import key7
    from je_auto_control.windows.core.util.win32_vk import key8
    from je_auto_control.windows.core.util.win32_vk import key9
    from je_auto_control.windows.core.util.win32_vk import keyA
    from je_auto_control.windows.core.util.win32_vk import keyB
    from je_auto_control.windows.core.util.win32_vk import keyC
    from je_auto_control.windows.core.util.win32_vk import keyD
    from je_auto_control.windows.core.util.win32_vk import keyE
    from je_auto_control.windows.core.util.win32_vk import keyF
    from je_auto_control.windows.core.util.win32_vk import keyG
    from je_auto_control.windows.core.util.win32_vk import keyH
    from je_auto_control.windows.core.util.win32_vk import keyI
    from je_auto_control.windows.core.util.win32_vk import keyJ
    from je_auto_control.windows.core.util.win32_vk import keyK
    from je_auto_control.windows.core.util.win32_vk import keyL
    from je_auto_control.windows.core.util.win32_vk import keyM
    from je_auto_control.windows.core.util.win32_vk import keyN
    from je_auto_control.windows.core.util.win32_vk import keyO
    from je_auto_control.windows.core.util.win32_vk import keyP
    from je_auto_control.windows.core.util.win32_vk import keyQ
    from je_auto_control.windows.core.util.win32_vk import keyR
    from je_auto_control.windows.core.util.win32_vk import keyS
    from je_auto_control.windows.core.util.win32_vk import keyT
    from je_auto_control.windows.core.util.win32_vk import keyU
    from je_auto_control.windows.core.util.win32_vk import keyV
    from je_auto_control.windows.core.util.win32_vk import keyW
    from je_auto_control.windows.core.util.win32_vk import keyX
    from je_auto_control.windows.core.util.win32_vk import keyY
    from je_auto_control.windows.core.util.win32_vk import keyZ
    from je_auto_control.windows.keyboard import win32_ctype_keyboard_control
    from je_auto_control.windows.mouse import win32_ctype_mouse_control
    from je_auto_control.windows.screen import screen

elif sys.platform == "darwin":
    pass

elif sys.platform not in ("darwin", "win32"):
    pass

else:
    raise Exception("unknown operating system")

from je_auto_control.util import template_detection



import sys

if sys.platform != "win32":
    raise Exception("win32_ctype_input should be only loaded on windows ")

from je_auto_control.windows.core.util.win32_ctype_input import Input
from je_auto_control.windows.core.util.win32_ctype_input import LEFTDOWN
from je_auto_control.windows.core.util.win32_ctype_input import LEFTUP
from je_auto_control.windows.core.util.win32_ctype_input import MIDDLEDOWN
from je_auto_control.windows.core.util.win32_ctype_input import MIDDLEUP
from je_auto_control.windows.core.util.win32_ctype_input import Mouse
from je_auto_control.windows.core.util.win32_ctype_input import MouseInput
from je_auto_control.windows.core.util.win32_ctype_input import RIGHTDOWN
from je_auto_control.windows.core.util.win32_ctype_input import RIGHTUP
from je_auto_control.windows.core.util.win32_ctype_input import SendInput
from je_auto_control.windows.core.util.win32_ctype_input import XBUTTON1
from je_auto_control.windows.core.util.win32_ctype_input import XBUTTON2
from je_auto_control.windows.core.util.win32_ctype_input import XDOWN
from je_auto_control.windows.core.util.win32_ctype_input import XUP
from je_auto_control.windows.core.util.win32_ctype_input import ctypes
from je_auto_control.windows.core.util.win32_ctype_input import windll
from je_auto_control.windows.core.util.win32_ctype_input import wintypes
from je_auto_control.windows.core.util.win32_ctype_mouse_event import mouse_event
from je_auto_control.windows.core.util.win32_vk import WHEEL
from je_auto_control.windows.screen.screen import size

left = (LEFTUP, LEFTDOWN, 0)
middle = (MIDDLEUP, MIDDLEDOWN, 0)
right = (RIGHTUP, RIGHTDOWN, 0)
x1 = (XUP, XDOWN, XBUTTON1)
x2 = (XUP, XDOWN, XBUTTON2)

get_cursor_pos = windll.user32.GetCursorPos
set_cursor_pos = windll.user32.SetCursorPos


def position():
    point = wintypes.POINT()
    if get_cursor_pos(ctypes.byref(point)):
        return point.x, point.y
    else:
        return None


def set_position(x, y):
    pos = x, y
    set_cursor_pos(*pos)


def press_mouse(pressButton):
    SendInput(1, ctypes.byref(
        Input(type=Mouse, _input=Input.INPUT_Union(
            mi=MouseInput(dwFlags=pressButton[1], mouseData=pressButton[2])))),
              ctypes.sizeof(Input))


def release_mouse(pressButton):
    SendInput(1, ctypes.byref(
        Input(type=Mouse, _input=Input.INPUT_Union(
            mi=MouseInput(dwFlags=pressButton[0], mouseData=pressButton[2])))),
              ctypes.sizeof(Input))


def scroll(wheel_value, x=None, y=None):
    now_cursor_x, now_cursor_y = position()
    width, height = size()
    if x is None:
        x = now_cursor_x
    else:
        if x < 0:
            x = 0
        elif x >= width:
            x = width - 1
    if y is None:
        y = now_cursor_y
    else:
        if y < 0:
            y = 0
        elif y >= height:
            y = height - 1
    mouse_event(WHEEL, x, y, dwData=wheel_value)



import sys

if sys.platform != "win32":
    raise Exception("win32_ctype_input should be only loaded on windows ")

# mouse

MOVE = 0x0001
LEFTDOWN = 0x0002
LEFTUP = 0x0004
RIGHTDOWN = 0x0008
RIGHTUP = 0x0010
MIDDLEDOWN = 0x0020
MIDDLEUP = 0x0040
XDOWN = 0x0080
XUP = 0x0100
WHEEL = 0x0800
HWHEEL = 0x1000
ABSOLUTE = 0x8000
XBUTTON1 = 0x0001
XBUTTON2 = 0x0002

VK_LBUTTON = 0x01
VK_RBUTTON = 0x02
VK_MBUTTON = 0x04
VK_XBUTTON1 = 0x05
VK_XBUTTON2 = 0x06

# keyboard

EventF_EXTENDEDKEY = 0x0001
EventF_KEYUP = 0x0002
EventF_UNICODE = 0x0004
EventF_SCANCODE = 0x0008

VkToVSC = 0
VK_CANCEL = 0x03
VK_BACK = 0x08  # BACKSPACE key
VK_TAB = 0x09  # TAB key
VK_CLEAR = 0x0C  # CLEAR key
VK_RETURN = 0x0D  # ENTER key
VK_SHIFT = 0x10  # SHIFT key
VK_CONTROL = 0x11  # CTRL key
VK_Menu = 0x12  # ALT key
VK_PAUSE = 0x13  # PAUSE key
VK_CAPITAL = 0x14  # CAPS LOCK key
VK_KANA = 0x15
VK_IME_ON = 0x16
VK_JUNJA = 0x17
VK_FINAL = 0x18  # ESC key
VK_HANJA = 0x19
VK_IME_OFF = 0x1A
VK_ESCAPE = 0x1B
VK_CONVERT = 0x1C
VK_NONCONVERT = 0x1D
VK_ACCEPT = 0x1E
VK_MODECHANGE = 0x1F
VK_SPACE = 0x20  # SPACEBAR
VK_PRIOR = 0x21  # PAGE UP key
VK_NEXT = 0x22  # PAGE DOWN key
VK_END = 0x23  # END key
VK_HOME = 0x24  # HOME key
VK_LEFT = 0x25  # LEFT ARROW key
VK_UP = 0x26
VK_RIGHT = 0x27
VK_DOWN = 0x28
VK_SELECT = 0x29
VK_PRINT = 0x2A
VK_EXECUTE = 0x2B
VK_SNAPSHOT = 0x2C
VK_INSERT = 0x2D
VK_DELETE = 0x2E
VK_HELP = 0x2F
key0 = 0x30
key1 = 0x31
key2 = 0x32
key3 = 0x33
key4 = 0x34
key5 = 0x35
key6 = 0x36
key7 = 0x37
key8 = 0x38
key9 = 0x39
keyA = 0x41
keyB = 0x42
keyC = 0x43
keyD = 0x44
keyE = 0x45
keyF = 0x46
keyG = 0x47
keyH = 0x48
keyI = 0x49
keyJ = 0x4A
keyK = 0x4B
keyL = 0x4C
keyM = 0X4D
keyN = 0x4E
keyO = 0x4F
keyP = 0x50
keyQ = 0x51
keyR = 0x52
keyS = 0x53
keyT = 0x54
keyU = 0x55
keyV = 0x56
keyW = 0x57
keyX = 0x58
keyY = 0x59
keyZ = 0x5A
VK_LWIN = 0x5B  # Left Windows key (Natural keyboard)
VK_RWIN = 0x5C  # Right Windows key (Natural keyboard)
VK_APPS = 0x5D  # Applications key (Natural keyboard)
VK_SLEEP = 0x5F  # Computer Sleep key
VK_NUMPAD0 = 0x60  # Numeric keypad 0 key
VK_NUMPAD1 = 0x61
VK_NUMPAD2 = 0x62
VK_NUMPAD3 = 0x63
VK_NUMPAD4 = 0x64
VK_NUMPAD5 = 0x65
VK_NUMPAD6 = 0x66
VK_NUMPAD7 = 0x67
VK_NUMPAD8 = 0x68
VK_NUMPAD9 = 0x69
VK_MULTIPLY = 0x6A  # Multiply key
VK_ADD = 0x6B  # Add key
VK_SEPARATOR = 0x6C  # Separator key
VK_SUBTRACT = 0x6D  # Subtract key
VK_DECIMAL = 0x6E  # Decimal key
VK_DIVIDE = 0x6F  # VK_DIVIDE
VK_F1 = 0x70  # F1
VK_F2 = 0x71
VK_F3 = 0x72
VK_F4 = 0x73
VK_F5 = 0x74
VK_F6 = 0x75
VK_F7 = 0x76
VK_F8 = 0x77
VK_F9 = 0x78
VK_F10 = 0x79
VK_F11 = 0x7A
VK_F12 = 0x7B
VK_F13 = 0x7C
VK_F14 = 0x7D
VK_F15 = 0x7E
VK_F16 = 0x7F
VK_F17 = 0x80
VK_F18 = 0x81
VK_F19 = 0x82
VK_F20 = 0x83
VK_F21 = 0x84
VK_F22 = 0x85
VK_F23 = 0x86
VK_F24 = 0x87
VK_NUMLOCK = 0x90  # NUM LOCK key
VK_SCROLL = 0x91  # SCROLL LOCK key
VK_LSHIFT = 0xA0  # Left SHIFT key
VK_RSHIFT = 0xA1
VK_LCONTROL = 0xA2  # Left CONTROL key
VK_RCONTROL = 0xA3  # Right CONTROL key
VK_LMENU = 0xA4  # Left MENU key
VK_RMENU = 0xA5  # Right MENU key
VK_BROWSER_BACK = 0xA6  # Browser Back key
VK_BROWSER_FORWARD = 0xA7  # Browser Forward key
VK_BROWSER_REFRESH = 0xA8  # Browser Refresh key
VK_BROWSER_STOP = 0xA9  # Browser Stop key
VK_BROWSER_SEARCH = 0xAA  # Browser Search key
VK_BROWSER_FAVORITES = 0xAB  # Browser Favorites key
VK_VOLUME_MUTE = 0xAD
VK_VOLUME_DOWN = 0xAE
VK_VOLUME_UP = 0xAF
VK_MEDIA_NEXT_TRACK = 0xB0
VK_MEDIA_PREV_TRACK = 0xB1
VK_MEDIA_STOP = 0xB2
VK_MEDIA_PLAY_PAUSE = 0xB3
VK_LAUNCH_MAIL = 0xB4
VK_LAUNCH_MEDIA_SELECT = 0xB5
VK_LAUNCH_APP1 = 0xB6
VK_LAUNCH_APP2 = 0xB7



import sys

if sys.platform != "win32":
    raise Exception("win32_ctype_input should be only loaded on windows ")

from je_auto_control.windows.core.util.win32_ctype_input import Input
from je_auto_control.windows.core.util.win32_ctype_input import Keyboard
from je_auto_control.windows.core.util.win32_ctype_input import KeyboardInput
from je_auto_control.windows.core.util.win32_ctype_input import SendInput
from je_auto_control.windows.core.util.win32_ctype_input import ctypes
from je_auto_control.windows.core.util.win32_ctype_input import EventF_KEYUP


def press_key(keyCode):
    x = Input(type=Keyboard, ki=KeyboardInput(wVk=keyCode))
    SendInput(1, ctypes.byref(x), ctypes.sizeof(x))


def release_key(keyCode):
    x = Input(type=Keyboard, ki=KeyboardInput(wVk=keyCode, dwFlags=EventF_KEYUP))
    SendInput(1, ctypes.byref(x), ctypes.sizeof(x))



from je_auto_control.linux_with_x11.core.display import display

key_backspace = display.keysym_to_keycode(Xlib.XK.string_to_keysym(BackSpace))
key_slash_b = display.keysym_to_keycode(Xlib.XK.string_to_keysym(BackSpace))
key_tab = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Tab))
key_enter = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_return = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_shift = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Shift_L))
key_ctrl = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Control_L))
key_alt = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Alt_L))
key_pause = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Pause))
key_capslock = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Caps_Lock))
key_esc = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Escape))
key_escape = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Escape))
key_pgup = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Up))
key_pgdn = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Down))
key_pageup = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Up))
key_pagedown = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Down))
key_end = display.keysym_to_keycode(Xlib.XK.string_to_keysym(End))
key_home = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Home))
key_left = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Left))
key_up = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Up))
key_right = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Right))
key_down = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Down))
key_select = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Select))
key_print = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_execute = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Execute))
key_prtsc = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_prtscr = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_prntscrn = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_printscreen = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_insert = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Insert))
key_del = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Delete))
key_delete = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Delete))
key_help = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Help))
key_win = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Super_L))
key_winleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Super_L))
key_winright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Super_R))
key_apps = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Menu))
key_num0 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_0))
key_num1 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_1))
key_num2 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_2))
key_num3 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_3))
key_num4 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_4))
key_num5 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_5))
key_num6 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_6))
key_num7 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_7))
key_num8 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_8))
key_num9 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_9))
key_multiply = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Multiply))
key_add = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Add))
key_separator = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Separator))
key_subtract = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Subtract))
key_decimal = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Decimal))
key_divide = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Divide))
key_f1 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F1))
key_f2 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F2))
key_f3 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F3))
key_f4 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F4))
key_f5 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F5))
key_f6 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F6))
key_f7 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F7))
key_f8 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F8))
key_f9 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F9))
key_f10 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F10))
key_f11 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F11))
key_f12 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F12))
key_f13 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F13))
key_f14 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F14))
key_f15 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F15))
key_f16 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F16))
key_f17 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F17))
key_f18 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F18))
key_f19 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F19))
key_f20 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F20))
key_f21 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F21))
key_f22 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F22))
key_f23 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F23))
key_f24 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F24))
key_numlock = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Num_Lock))
key_scrolllock = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Scroll_Lock))
key_shiftleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Shift_L))
key_shiftright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Shift_R))
key_ctrlleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Control_L))
key_ctrlright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Control_R))
key_altleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Alt_L))
key_altright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Alt_R))
key_space = display.keysym_to_keycode(Xlib.XK.string_to_keysym(space))
key_newline_n = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_newline_r = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_newline_t = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Escape))
key_exclam = display.keysym_to_keycode(Xlib.XK.string_to_keysym(exclam))
key_numbersign = display.keysym_to_keycode(Xlib.XK.string_to_keysym(numbersign))
key_percent = display.keysym_to_keycode(Xlib.XK.string_to_keysym(percent))
key_dollar = display.keysym_to_keycode(Xlib.XK.string_to_keysym(dollar))
key_ampersand = display.keysym_to_keycode(Xlib.XK.string_to_keysym(ampersand))
key_quotedbl = display.keysym_to_keycode(Xlib.XK.string_to_keysym(quotedbl))
key_apostrophe = display.keysym_to_keycode(Xlib.XK.string_to_keysym(apostrophe))
key_parenleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(parenleft))
key_parenright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(parenright))
key_asterisk = display.keysym_to_keycode(Xlib.XK.string_to_keysym(asterisk))
key_equal = display.keysym_to_keycode(Xlib.XK.string_to_keysym(equal))
key_plus = display.keysym_to_keycode(Xlib.XK.string_to_keysym(plus))
key_comma = display.keysym_to_keycode(Xlib.XK.string_to_keysym(comma))
key_minus = display.keysym_to_keycode(Xlib.XK.string_to_keysym(minus))
key_period = display.keysym_to_keycode(Xlib.XK.string_to_keysym(period))
key_slash = display.keysym_to_keycode(Xlib.XK.string_to_keysym(slash))
key_colon = display.keysym_to_keycode(Xlib.XK.string_to_keysym(colon))
key_semicolon = display.keysym_to_keycode(Xlib.XK.string_to_keysym(semicolon))
key_less = display.keysym_to_keycode(Xlib.XK.string_to_keysym(less))
key_greater = display.keysym_to_keycode(Xlib.XK.string_to_keysym(greater))
key_question = display.keysym_to_keycode(Xlib.XK.string_to_keysym(question))
key_at = display.keysym_to_keycode(Xlib.XK.string_to_keysym(at))
key_bracketleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(bracketleft))
key_bracketright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(bracketright))
key_backslash = display.keysym_to_keycode(Xlib.XK.string_to_keysym(backslash))
key_asciicircum = display.keysym_to_keycode(Xlib.XK.string_to_keysym(asciicircum))
key_underscore = display.keysym_to_keycode(Xlib.XK.string_to_keysym(underscore))
key_grave = display.keysym_to_keycode(Xlib.XK.string_to_keysym(grave))
key_braceleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(braceleft))
key_bar = display.keysym_to_keycode(Xlib.XK.string_to_keysym(bar))
key_braceright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(braceright))
key_asciitilde = display.keysym_to_keycode(Xlib.XK.string_to_keysym(asciitilde))



from Xlib import X
from Xlib.ext.xtest import fake_input

from je_auto_control.linux_with_x11.core.display import display


def position():
    coord = display.screen().root.query_pointer()._data
    return coord["root_x"], coord["root_y"]


def set_position(x, y):
    fake_input(_display, X.MotionNotify, x=x, y=y)
    display.sync()
